pub(crate) fn named_solver_command(
solver: &str,
) -> Result<SolverCommand, SolverConfigError>Expand description
Returns the default command for a known solver name.
pub(crate) fn named_solver_command(
solver: &str,
) -> Result<SolverCommand, SolverConfigError>Returns the default command for a known solver name.