fn run_solver_process(
command: &SolverCommand,
smt: &str,
timeout: Option<u32>,
cancel: &AtomicBool,
) -> SolverProcessOutcomeExpand description
Runs one solver process to completion, timeout, or cooperative cancellation.
fn run_solver_process(
command: &SolverCommand,
smt: &str,
timeout: Option<u32>,
cancel: &AtomicBool,
) -> SolverProcessOutcomeRuns one solver process to completion, timeout, or cooperative cancellation.