fn solver_command_availability_error(command: &SolverCommand) -> Option<String>Expand description
Returns why command is not currently executable as an SMT solver.
fn solver_command_availability_error(command: &SolverCommand) -> Option<String>Returns why command is not currently executable as an SMT solver.